@@ -118,7 +118,7 @@ class App:
 
         if path_info.startswith("/static") or path_info.startswith("static"):
             scope["PATH_INFO"] = path_info[len("/static"):]
-            return self.static_app(scope, recieve, send)
+            await self.static_app(scope, recieve, send)
 
         await self.middleware(scope, recieve, send)
 
